@@ -11,10 +11,11 @@
 #define QUERY_COLOCATION_CHECKER_H
 
 
-#include "distributed/distributed_planner.h"
 #include "nodes/parsenodes.h"
 #include "nodes/primnodes.h"
 
+#include "distributed/distributed_planner.h"
+
 
 /*
  * ColocatedJoinChecker is a helper structure that is used to decide
@@ -38,5 +39,7 @@ extern Query * WrapRteRelationIntoSubquery(RangeTblEntry *rteRelation,
 										   List *requiredAttributes,
 										   RTEPermissionInfo *perminfo);
 extern List * CreateAllTargetListForRelation(Oid relationId, List *requiredAttributes);
+extern List * CreateFilteredTargetListForRelation(Oid relationId,
+												  List *requiredAttributes);
 
 #endif /* QUERY_COLOCATION_CHECKER_H */
